"use strict";
/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadVcConfig = exports.mapFunctionPathToFunctionName = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const constants_1 = require("./constants");
// Map a function's path to its function name route
// eg:
//    /functions/index.func          -> index
//    /functions/foo/bar.func        -> foo/bar
//    /functions/foo/bar/index.func  -> foo/bar/index
function mapFunctionPathToFunctionName(functionPath) {
    if (!functionPath.startsWith('/functions/')) {
        throw new Error(`Function path must start with /functions/, received '${functionPath}'.`);
    }
    let functionName = functionPath.slice('/functions/'.length);
    functionName = functionName.slice(0, functionName.lastIndexOf('.func'));
    return functionName;
}
exports.mapFunctionPathToFunctionName = mapFunctionPathToFunctionName;
function loadVcConfig(functionPath) {
    // Loads the "vercel config file" (.vc-config.json)
    // or, returns null, if it is not any of the known config file types
    const vcConfigFilePath = path_1.default.join(functionPath, constants_1.VERCEL_FUNCTION_CONFIG_FILENAME);
    let vcConfigFile;
    try {
        const vcConfigFileJson = fs_1.default.readFileSync(vcConfigFilePath, 'utf-8');
        vcConfigFile = JSON.parse(vcConfigFileJson);
    }
    catch (ex) {
        throw new Error('Error loading vercel config file \'' + vcConfigFilePath + '\'.', { cause: ex });
    }
    if (vcConfigFile.runtime === 'edge' &&
        vcConfigFile.deploymentTarget === 'v8-worker') {
        return vcConfigFile;
    }
    if (vcConfigFile.runtime.startsWith('nodejs')) {
        return vcConfigFile;
    }
    return null;
}
exports.loadVcConfig = loadVcConfig;
