"use strict";
/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const EMPTY_MODULE = path_1.default.resolve(__dirname, '../../server/lib/empty-module');
function webpackTransform(config, webpack) {
    return {
        ...config,
        plugins: [
            ...config.plugins ?? [],
            new webpack.ProvidePlugin({
                Buffer: ['buffer', 'Buffer'],
                process: 'process',
            }),
            new webpack.EnvironmentPlugin({
                NEXT_RUNTIME: 'edge',
            }),
            new webpack.optimize.LimitChunkCountPlugin({
                maxChunks: 1,
            }),
            new webpack.NormalModuleReplacementPlugin(/\/lib\/server-ipc\/invoke-request$/, EMPTY_MODULE),
        ],
        resolve: {
            ...config.resolve,
            alias: {
                ...config.resolve?.alias,
                'next/dist/compiled/raw-body': require.resolve('raw-body'),
                'react-dom/server.edge$': EMPTY_MODULE,
                'react-server-dom-webpack/client$': EMPTY_MODULE,
                'react-server-dom-webpack/client.edge$': EMPTY_MODULE,
                'react-server-dom-webpack/server.edge$': EMPTY_MODULE,
                'react-server-dom-webpack/server.node$': EMPTY_MODULE,
            },
            fallback: {
                ...config.resolve?.fallback,
                url: require.resolve('url/'),
                "@builder.io/partytown/integration": false,
                "buffer": require.resolve("buffer/"),
                "crypto": require.resolve("crypto-browserify/"),
                "events": require.resolve("events/"),
                "stream": require.resolve("stream-browserify"),
                "os": require.resolve("os-browserify/browser"),
                "path": require.resolve("path-browserify"),
                "process": require.resolve("process/browser"),
                "querystring": require.resolve("querystring-es3"),
                "util": require.resolve("util/"),
            },
        },
    };
}
exports.default = webpackTransform;
